@@ -839,10 +839,22 @@ class Entries(ClientFunctionSet):
         if isinstance(entry_id, numbers.Number) or isinstance(entry_id, str):
             return self._client._request(action='protein', subject=entry_id)
         else:
-            return self._client._request(action='protein',
-                                         subject='bulk_retrieve',
-                                         data={'ids': list(entry_id)},
-                                         request_type='post')
+            is_list = isinstance(entry_id, list)
+            entry_ids = list(entry_id)
+            z = self._client._request(action='protein',
+                                      subject='bulk_retrieve',
+                                      data={'ids': entry_ids},
+                                      request_type='post')
+            if not is_list:
+                # set, dictionary keys, etc. anything that list(x) works on
+                return {x.query_id: x.target for x in z}
+            else:
+                # possibly out of order
+                e2i = dict(map(lambda x: (x[1], x[0]), enumerate(entry_ids)))
+                res = [None] * len(entry_ids)
+                for x in z:
+                    res[e2i[x.query_id]] = x.target
+            return res
 
     def domains(self, entry_id):
         '''
